@@ -14,7 +14,11 @@ VERBOSE = 3
 BEANSTALK_STACK_BASE = '/var/beanstalk'
 STATIC_URL_PREFIX = 'static'
 BEANSTALK_EMAIL = 'beanstalk@beanstalk-stack.com'
+UWSGI_COMMAND = '/usr/local/bin/uwsgi'
+RUN_LOCATION = '/var/run/beanstalk'
 
+# Hooked Actions
+#-----------------------------------------------------------------------------------------------------------------------
 PRE_SETUP_ACTIONS = []  # Only beanstalk settings
 POST_SETUP_ACTIONS = []  # Only beanstalk settings
 
